Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(493)

Unified Diff: chrome/browser/safe_browsing/client_side_detection_host.h

Issue 21170004: Store and return urls instead of hosts for the malware IP matching. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/safe_browsing/client_side_detection_host.h
diff --git a/chrome/browser/safe_browsing/client_side_detection_host.h b/chrome/browser/safe_browsing/client_side_detection_host.h
index 7f3e93ee4023c885598e5787a614f51f71e06da6..95436526ef23aa1ebcd67a65bacbed186f03a2f7 100644
--- a/chrome/browser/safe_browsing/client_side_detection_host.h
+++ b/chrome/browser/safe_browsing/client_side_detection_host.h
@@ -79,7 +79,7 @@ class ClientSideDetectionHost : public content::WebContentsObserver,
void MalwareFeatureExtractionDone(scoped_ptr<ClientMalwareRequest> request);
// Update the entries in browse_info_->ips map.
- void UpdateIPHostMap(const std::string& ip, const std::string& host);
+ void UpdateIPUrlMap(const std::string& ip, const std::string& url);
// From NotificationObserver. Called when a notification comes in. This
// method is called in the UI thread.
@@ -131,8 +131,8 @@ class ClientSideDetectionHost : public content::WebContentsObserver,
// Max number of ips we save for each browse
static const int kMaxIPsPerBrowse;
- // Max number of hosts we report for each malware IP.
- static const int kMaxHostsPerIP;
+ // Max number of urls we report for each malware IP.
+ static const int kMaxUrlsPerIP;
base::WeakPtrFactory<ClientSideDetectionHost> weak_factory_;

Powered by Google App Engine
This is Rietveld 408576698